This file is outdated and present only for downwards compatibility of links.

Please visit instead:
* the [aeon API reference](https://www.aeon-toolkit.org/en/stable/api_reference.html)
* the [tabular estimator overview](https://www.aeon-toolkit.org/en/stable/estimator_overview.html)
